| EER | R Documentation |
From two vectors of false positive and false negative rates that define the points of the curve, the function computes the Equal Error Rate (EER).
EER(fpr, fnr)
fpr |
A numeric vector representing the false positive rates. |
fnr |
A numeric vector representing the false negative rates. |
The Equal Error Rate (EER).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.