minDcf: Minimum of the Detection Cost Function computation

View source: R/measures.R

minDcfR Documentation

Minimum of the Detection Cost Function computation

Description

From a 'DET' object, the function computes the minimum value of the Detection Cost Function (minDCF).

Usage

minDcf(det, p = 0.01, cFp = 1, cFn = 10)

Arguments

det

An object of class "DET".

p

A single numeric value in the (0, 1) interval representing the prior probability of the positive class.

cFp

A single numeric value representing the cost of false positives.

cFn

A single numeric value representing the cost of false negatives.

Value

A list with five attributes:

- 'minDcfValue': the computed minDCF.

- 'minDcfIndex': the index of the fpr and fnr in which the minimum is reached.

- 'minDcf_threshold': the cut-off point in which the minimum is reached.

- 'minDcf_fpr': the fpr value in which the minimum is reached.

- 'minDcf_fnr': the fnr value in which the minimum is reached.


DET documentation built on June 15, 2026, 9:08 a.m.

Related to minDcf in DET...