show.DETs: Show the structure of a DET object

View source: R/show.R

show.DETsR Documentation

Show the structure of a DET object

Description

From a 'DETs' object (generated with the detc function), the function shows the different attributes of each curve with a brief description, which have to be used to get the results for each curve.

Usage

show.DETs(dets)

Arguments

dets

An object of class "DETs".


DET documentation built on June 15, 2026, 9:08 a.m.