speaker: Data on a Speaker Recognition System (Voxceleb verification...

speakerR Documentation

Data on a Speaker Recognition System (Voxceleb verification test)

Description

For our experiments, we have used the Voxceleb database, which contains more than one hundred thousand utterances extracted from YouTube interview videos. The database includes training and test sets that can be used for speaker recognition system development and performance evaluation respectively. The test protocol consists of a list of utterance pairs, with the corresponding target or nontarget label, and the task is to detect whether the two utterances belong to the same speaker or to different speakers.

Usage

data(speaker)

Format

An object of class "data.frame".

Web Archive

References

Nagrani A, Chung JS, Zisserman A (2017). Proceedings of the Annual Conference of the International Speech Communication Association, 950:2616–2620 (Publication)

Examples

library(DET)
data(speaker)
scoresLDA = speaker$scoresLDA
scoresPLDA = speaker$scoresPLDA
scoresLDAPLDA = speaker$scoresLDAPLDA
predictors = matrix(c(as.numeric(scoresLDA),
                      as.numeric(scoresPLDA),
                      as.numeric(scoresLDAPLDA)), ncol = 3)
colnames(predictors) = c("LDA", "PLDA", "LDAandPLDA")
response = as.factor(speaker$keys$V3)
detCurves =
  detc(
    response,
    predictors,
    names = colnames(predictors),
    positive = "target"
  )
plot(detCurves, main = "Voxceleb verification test")


DET documentation built on June 15, 2026, 9:08 a.m.

Related to speaker in DET...