| minDcf | R Documentation |
From a 'DET' object, the function computes the minimum value of the Detection Cost Function (minDCF).
minDcf(det, p = 0.01, cFp = 1, cFn = 10)
det |
An object of class "DET". |
p |
A single numeric value in the (0, 1) interval representing the prior probability of the positive class. |
cFp |
A single numeric value representing the cost of false positives. |
cFn |
A single numeric value representing the cost of false negatives. |
A list with five attributes:
- 'minDcfValue': the computed minDCF.
- 'minDcfIndex': the index of the fpr and fnr in which the minimum is reached.
- 'minDcf_threshold': the cut-off point in which the minimum is reached.
- 'minDcf_fpr': the fpr value in which the minimum is reached.
- 'minDcf_fnr': the fnr value in which the minimum is reached.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.